@@ -66,10 +66,16 @@ def get_equal_groups(data_df,group_count,variable_name):
 
     temp_df = dict_df.reset_index(inplace=False)
 
+    min_df = min_df.round({col_name: 2})
+    max_df = max_df.round({col_name: 2})
+
     min_df = temp_df.groupby([col_name]).min().astype(str)
     max_df = temp_df.groupby([col_name]).max().astype(str)
 
     full_gp_name_df = pd.merge(min_df, max_df, left_index=True, right_index=True)
+
+
+
     full_gp_name_df[(col_name+'_rg')] = (full_gp_name_df['index_x']) + "-To-" + (full_gp_name_df['index_y'])
     return_df = pd.merge(full_gp_name_df, temp_df, left_on=col_name, right_on=col_name)
     return_df = return_df[[col_name,(col_name+'_rg'),'index']]
@@ -708,10 +714,10 @@ def nlp_split(note,end_str,start_str):
 # =======================================================
 #
 # =======================================================
-def nlp_cluster(data_df,cluster_column,clusters,prediction_col,max_df_val,min_df_val,max_iter_val,n_init_val,cluster_algo):
+def nlp_cluster(data_df,cluster_column,clusters,prediction_col,max_df_val,min_df_val,max_iter_val,n_init_val,cluster_algo,ngram_range_val):
     """ Text """
 
-    vectorizer = TfidfVectorizer(stop_words='english',use_idf = True, lowercase  = True, max_df = max_df_val, min_df = min_df_val)
+    vectorizer = TfidfVectorizer(stop_words='english',use_idf = True, lowercase  = True, max_df = max_df_val, min_df = min_df_val, ngram_range = ngram_range_val)
     X = vectorizer.fit_transform(data_df[cluster_column].values)
 
     model = KMeans(n_clusters=clusters, init='k-means++', max_iter=max_iter_val, n_init=n_init_val, algorithm='auto',n_jobs = -1,verbose=True)
